import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { is, fromJS } from 'immutable'
import { Modal } from 'antd'
import { ClockCircleOutlined } from '@ant-design/icons'

import ClockForm from './settingform'
import './index.scss'

class ClockComponent extends Component {
  static propTpyes = {
    updateConfig: PropTypes.func
  }

  state = {
    visible: false
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState))
  }

  trigger = () => {
    this.setState({
      visible: true
    })
  }

  submit = () => {
    const { config } = this.props

    this.verifyRef.handleConfirm().then(res => {
      this.setState({
        visible: false
      })
      this.props.updateConfig({...config, timer: res.timer, clearField: res.clearField || '', clearValue: res.clearValue || ''})
    })
  }

  render () {
    const { config } = this.props
    const { visible, loading } = this.state

    return (
      <div className="clock-component-wrap">
        <ClockCircleOutlined title="定时器" onClick={this.trigger} />
        <Modal
          title="定时器设置"
          visible={visible}
          width={500}
          maskClosable={false}
          confirmLoading={loading}
          onOk={this.submit}
          onCancel={() => this.setState({ visible: false })}
          destroyOnClose
        >
          <ClockForm config={config} inputSubmit={this.submit} wrappedComponentRef={(inst) => this.verifyRef = inst}/>
        </Modal>
      </div>
    )
  }
}

export default ClockComponent